from ..utils.appEngine import AppEngine


class Environment:

    production = "production"
    development = "development"

    @classmethod
    def current(cls):
        projectId = AppEngine.getProjectId()
        return cls.development if "dev" in projectId else cls.production


class Microservice:

    transfer = "transfer"
    charge = "charge"
    refund = "refund"
    workspace = "workspace"
    bank = "bank"
    gateway = "gateway"

    @classmethod
    def getBaseUrl(cls, ms):
        return {
            Environment.production:  _productionUrls.get(ms),
            Environment.development: _developmentUrls.get(ms)
        }[Environment.current()]


class Webapp:

    @classmethod
    def getBaseUrl(cls):
        return {
            Environment.production: "https://darwin-web.appspot.com",
            Environment.development: "http://web.darwin-ms-dev.appspot.com"
        }[Environment.current()]


_developmentUrls = {
    Microservice.transfer:  "https://darwin-ms-transfer-dev.appspot.com",
    Microservice.charge:    "https://darwin-ms-charge-dev.appspot.com",
    Microservice.refund:    "https://msrefund-dot-darwin-ms-dev.appspot.com",
    Microservice.workspace: "https://darwin-ms-workspace-dev.appspot.com",
    Microservice.bank:      "https://darwin-ms-bank-dev.appspot.com",
    Microservice.gateway:   "https://darwin-ms-gateway-dev.appspot.com"
}

_productionUrls = {
    Microservice.transfer:  "https://darwin-ms-transfer.appspot.com",
    Microservice.charge:    "https://darwin-ms-charge.appspot.com",
    Microservice.refund:    "https://darwin-ms-refund.appspot.com",
    Microservice.workspace: "https://darwin-ms-workspace.appspot.com",
    Microservice.bank:      "https://darwin-ms-bank.appspot.com",
    Microservice.gateway:   "https://darwin-ms-gateway.appspot.com"
}